@@ -244,9 +244,9 @@ class ApiGatewayToLambdaProps:
         :param log_group_props: User provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
         '''
         if isinstance(lambda_function_props, dict):
-            lambda_function_props = FunctionProps(**lambda_function_props)
+            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
         if isinstance(log_group_props, dict):
-            log_group_props = LogGroupProps(**log_group_props)
+            log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
         if __debug__:
             type_hints = typing.get_type_hints(ApiGatewayToLambdaProps.__init__)
             check_type(argname="argument api_gateway_props", value=api_gateway_props, expected_type=type_hints["api_gateway_props"])
